:orphan:

Example Programs
================

Play a Sound File
-----------------

:download:`play_file.py <../examples/play_file.py>`

.. literalinclude:: ../examples/play_file.py

Input to Output Pass-Through
----------------------------

:download:`wire.py <../examples/wire.py>`

.. literalinclude:: ../examples/wire.py

Real-Time Text-Mode Spectrogram
-------------------------------

:download:`spectrogram.py <../examples/spectrogram.py>`

.. literalinclude:: ../examples/spectrogram.py
